@@ -99,7 +99,7 @@ gpointer get_combo_value(GtkWidget *Acombo)
   GtkTreeModel *Lmodel = gtk_combo_box_get_model(GTK_COMBO_BOX(Acombo));
   GtkTreeIter Liter;
   gpointer *Lvalue = NULL;
-  if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(Acombo), &Liter)) return g_strdup("");
+  if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(Acombo), &Liter)) return NULL;
 
   gtk_tree_model_get(Lmodel, &Liter, 0, &Lvalue, -1);
 
@@ -329,10 +329,14 @@ void exit_prog(gint Apid, gboolean Aabort, GError **Aerror, gchar *Adefmsg)
 {
   gint Lcmdstatus = 0;
 
-  if (Aabort) kill(Apid, SIGTERM);
+  if (Aabort) {
+    kill(Apid, SIGTERM);
+    sleep(1);
+    kill(Apid, SIGTERM);
+  }
   waitpid(Apid, &Lcmdstatus, 0);
   if ((WIFEXITED(Lcmdstatus) && WEXITSTATUS(Lcmdstatus)!=0) || (!(WIFEXITED(Lcmdstatus)))) {
-    _DEB("oui une erreur\n");
+    _DEB("oui une erreur [%d]\n", Lcmdstatus);
     if (Aerror && !*Aerror) {
       g_set_error(Aerror, GRAVEMAN_ERROR, _ERR_UNKNOWN_ERROR, Adefmsg ? Adefmsg : _("Operation failed"));
     }
@@ -438,7 +442,7 @@ gdouble get_pourcent(gchar *Atotal, gchar *Aactu)
   return (1.0/Lnumtotal) * Lnumactu;
 }
 
-gchar *next_no_numeric(gchar *Ade)
+gchar *tools_next_no_numeric(gchar *Ade)
 {
   gchar *Lret = Ade;
 
@@ -447,7 +451,16 @@ gchar *next_no_numeric(gchar *Ade)
   return *Lret ? Lret : NULL;
 }
 
-gchar *next_putzero(gchar *Asource, gchar Asrc)
+gchar *tools_next_no_char(gchar *Ade, gchar Acar)
+{
+  gchar *Lret = Ade;
+
+  while (*Lret == Acar) Lret++;
+
+  return *Lret ? Lret : NULL;
+}
+
+gchar *tools_next_putzero(gchar *Asource, gchar Asrc)
 {
   gchar *s;
   if ((s=strchr(Asource, Asrc))) {
@@ -483,6 +496,24 @@ gboolean read_all_output_callback(GIOChannel *Astd, GIOCondition Acond, gpointer
   return TRUE;
 }
 
+/* escape each of 'Aescape' characters who are present in Abuf */
+gchar *sc_escape(gchar *Abuf, gint Asizemax, gchar *Aescape)
+{
+  gchar *Adbl = g_strdup(Abuf);
+  gint i, j;
+
+  for (i=0, j=0; i < Asizemax && j < Asizemax-1 && Adbl[i]; i++) {
+    if (strchr(Aescape, Adbl[i])) {
+      Abuf[j++]='\\';
+    }
+    Abuf[j++]=Adbl[i];
+  }
+  g_free(Adbl);
+  Abuf[j]=0;
+ 
+  return Abuf; 
+}
+
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
